@@ -484,8 +484,8 @@
 #define PROLOG_DIALECT "gprolog"
 #define PROLOG_NAME "GNU Prolog"
 #define PROLOG_VERSION "1.5.0"
-#define PROLOG_DATE "Apr 23 2022"
-#define PROLOG_COPYRIGHT "Copyright (C) 1999-2022 Daniel Diaz"
+#define PROLOG_DATE "Nov 14 2025"
+#define PROLOG_COPYRIGHT "Copyright (C) 1999-2025 Daniel Diaz"
 
 #define TOP_LEVEL "gprolog"
 #define GPLC "gplc"
@@ -498,9 +498,9 @@
 
 #define CC "gcc"
 #define CFLAGS_PREFIX_REG "-ffixed-%s"
-#define CFLAGS "-march=x86-64 -mtune=generic -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         -fstack-clash-protection -fcf-protection -fcommon -fPIC -Wno-char-subscripts"
+#define CFLAGS "-march=x86-64 -mtune=generic -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat -Werror=format-security         -fstack-clash-protection -fcf-protection         -fno-omit-frame-pointer -mno-omit-leaf-frame-pointer -g -ffile-prefix-map=/build/gprolog/src=/usr/src/debug/gprolog -std=gnu17 -fPIC -Wno-char-subscripts"
 #define CFLAGS_MACHINE " -fno-strict-aliasing -fcommon"
-#define LDFLAGS "-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now"
+#define LDFLAGS "-Wl,-O1 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro -Wl,-z,now          -Wl,-z,pack-relative-relocs"
 #define LDLIBS "-lm"
 #define AS "as"
 #define ASFLAGS "--64"
