@@ -76,8 +76,8 @@ extern "C" {
 #define PROLOG_DIALECT  	"gprolog"
 #define PROLOG_NAME     	"GNU Prolog"
 #define PROLOG_VERSION  	"1.5.0"
-#define PROLOG_DATE     	"Apr 23 2022"
-#define PROLOG_COPYRIGHT	"Copyright (C) 1999-2022 Daniel Diaz"
+#define PROLOG_DATE     	"Nov 14 2025"
+#define PROLOG_COPYRIGHT	"Copyright (C) 1999-2025 Daniel Diaz"
 
 #define PL_MIN_INTEGER		-1152921504606846976
 #define PL_MAX_INTEGER		1152921504606846975
